From 5e9e36b7a0bcfca992c6a82e104be892efee6a60 Mon Sep 17 00:00:00 2001
From: Guillem Jover <guillem@debian.org>
Date: Mon, 21 Oct 2019 23:35:32 +0200
Subject: [PATCH] autoconf.pm: Do not check for unknown
 --disable/enable/with/without-* options

By default autoconf will check for unknown --disable/enable/with/withouth-*
options and will emit a warning on standard error. This can be tuned by
the upstream maintainer with the AC_DISABLE_OPTION_CHECKING macro, to
make these fatal, or to not perform the checks by default.

Given that we unconditionally pass possibly unknown options to the
configure scripts, we should disable these checks to avoid emitting
warnings, which are at least confusing, and at worse might trip over
CI and test suite that check for output on standard error as markers
for failure.

Signed-off-by: Guillem Jover <guillem@debian.org>
---
 lib/Debian/Debhelper/Buildsystem/autoconf.pm | 3 +++
 t/buildsystems/autoconf/configure            | 1 +
 2 files changed, 4 insertions(+)

diff --git a/lib/Debian/Debhelper/Buildsystem/autoconf.pm b/lib/Debian/Debhelper/Buildsystem/autoconf.pm
index 37172eea..13cec219 100644
--- a/lib/Debian/Debhelper/Buildsystem/autoconf.pm
+++ b/lib/Debian/Debhelper/Buildsystem/autoconf.pm
@@ -38,6 +38,9 @@ sub configure {
 	push @opts, "--infodir=\${prefix}/share/info";
 	push @opts, "--sysconfdir=/etc";
 	push @opts, "--localstatedir=/var";
+	# We pass --disable/enable-* options that might be unknown, so we
+	# should not emit warnings.
+	push @opts, "--disable-option-checking";
 	if ($dh{QUIET}) {
 		push @opts, "--enable-silent-rules";
 	} else {
diff --git a/t/buildsystems/autoconf/configure b/t/buildsystems/autoconf/configure
index 07e416ce..50397837 100755
--- a/t/buildsystems/autoconf/configure
+++ b/t/buildsystems/autoconf/configure
@@ -14,6 +14,7 @@ my @OPTIONS=qw(
    ^--sysconfdir=/etc$
    ^--localstatedir=/var$
    ^--libdir=\$\{prefix\}/lib/.*$
+   ^--disable-option-checking$
    ^--disable-silent-rules$
    ^--disable-maintainer-mode$
    ^--disable-dependency-tracking$
-- 
2.24.0.rc0.303.g954a862665

